Index: src/x64/macro-assembler-x64.h |
diff --git a/src/x64/macro-assembler-x64.h b/src/x64/macro-assembler-x64.h |
index 2ab05cf1ac91a9ccac63da830dd256c25f061ca6..d204140c0c535dbddeb3bbbf4815269a7b6fd766 100644 |
--- a/src/x64/macro-assembler-x64.h |
+++ b/src/x64/macro-assembler-x64.h |
@@ -773,29 +773,22 @@ class MacroAssembler: public Assembler { |
Label::Distance near_jump = Label::kFar); |
- void JumpIfNotBothSequentialAsciiStrings( |
- Register first_object, |
- Register second_object, |
- Register scratch1, |
- Register scratch2, |
- Label* on_not_both_flat_ascii, |
+ void JumpIfNotBothSequentialOneByteStrings( |
+ Register first_object, Register second_object, Register scratch1, |
+ Register scratch2, Label* on_not_both_flat_one_byte, |
Label::Distance near_jump = Label::kFar); |
- // Check whether the instance type represents a flat ASCII string. Jump to the |
- // label if not. If the instance type can be scratched specify same register |
- // for both instance type and scratch. |
- void JumpIfInstanceTypeIsNotSequentialAscii( |
- Register instance_type, |
- Register scratch, |
- Label*on_not_flat_ascii_string, |
+ // Check whether the instance type represents a flat one-byte string. Jump |
+ // to the label if not. If the instance type can be scratched specify same |
+ // register for both instance type and scratch. |
+ void JumpIfInstanceTypeIsNotSequentialOneByte( |
+ Register instance_type, Register scratch, |
+ Label* on_not_flat_one_byte_string, |
Label::Distance near_jump = Label::kFar); |
- void JumpIfBothInstanceTypesAreNotSequentialAscii( |
- Register first_object_instance_type, |
- Register second_object_instance_type, |
- Register scratch1, |
- Register scratch2, |
- Label* on_fail, |
+ void JumpIfBothInstanceTypesAreNotSequentialOneByte( |
+ Register first_object_instance_type, Register second_object_instance_type, |
+ Register scratch1, Register scratch2, Label* on_fail, |
Label::Distance near_jump = Label::kFar); |
void EmitSeqStringSetCharCheck(Register string, |
@@ -1206,12 +1199,9 @@ class MacroAssembler: public Assembler { |
Register scratch2, |
Register scratch3, |
Label* gc_required); |
- void AllocateAsciiString(Register result, |
- Register length, |
- Register scratch1, |
- Register scratch2, |
- Register scratch3, |
- Label* gc_required); |
+ void AllocateOneByteString(Register result, Register length, |
+ Register scratch1, Register scratch2, |
+ Register scratch3, Label* gc_required); |
// Allocate a raw cons string object. Only the map field of the result is |
// initialized. |
@@ -1219,10 +1209,8 @@ class MacroAssembler: public Assembler { |
Register scratch1, |
Register scratch2, |
Label* gc_required); |
- void AllocateAsciiConsString(Register result, |
- Register scratch1, |
- Register scratch2, |
- Label* gc_required); |
+ void AllocateOneByteConsString(Register result, Register scratch1, |
+ Register scratch2, Label* gc_required); |
// Allocate a raw sliced string object. Only the map field of the result is |
// initialized. |
@@ -1230,10 +1218,8 @@ class MacroAssembler: public Assembler { |
Register scratch1, |
Register scratch2, |
Label* gc_required); |
- void AllocateAsciiSlicedString(Register result, |
- Register scratch1, |
- Register scratch2, |
- Label* gc_required); |
+ void AllocateOneByteSlicedString(Register result, Register scratch1, |
+ Register scratch2, Label* gc_required); |
// --------------------------------------------------------------------------- |
// Support functions. |